@@ -11,15 +11,13 @@ Generate queries using the SOQL dialect.
 from django.db.models.sql import compiler, query, where, constants
 from django.db.models.sql.datastructures import EmptyResultSet
 
-import django
-from pkg_resources import parse_version
-DJANGO_14 = (parse_version(django.get_version()) >= parse_version('1.4'))
-DJANGO_16 = django.VERSION[:2] >= (1,6)
+from salesforce import DJANGO_14, DJANGO_15, DJANGO_16
+
 
 def process_name(name):
 	"""
 	Convert a Djangofied column name into a Salesforce-compliant column name.
-	
+
 	TODO: this is sketchy
 	"""
 	if(name.startswith('example_')):
@@ -57,7 +55,7 @@ class SQLCompiler(compiler.SQLCompiler):
 				name = col
 			result.append(name.strip('"'))
 		return (result, col_params) if DJANGO_16 else result
-	
+
 	def get_from_clause(self):
 		"""
 		Return the FROM clause, converted the SOQL dialect.
@@ -77,7 +75,7 @@ class SQLCompiler(compiler.SQLCompiler):
 			result.append('%s%s' % (connector, name))
 			first = False
 		return result, []
-	
+
 	def quote_name_unless_alias(self, name):
 		"""
 		A wrapper around connection.ops.quote_name that doesn't quote aliases
@@ -86,7 +84,7 @@ class SQLCompiler(compiler.SQLCompiler):
 		r = self.connection.ops.quote_name(name)
 		self.quote_cache[name] = r
 		return r
-	
+
 	def execute_sql(self, result_type=constants.MULTI):
 		"""
 		Run the query against the database and returns the result(s). The
@@ -112,10 +110,10 @@ class SQLCompiler(compiler.SQLCompiler):
 
 		cursor = self.connection.cursor(self.query)
 		cursor.execute(sql, params)
-		
+
 		if not result_type:
 			return cursor
-		
+
 		ordering_aliases = self.ordering_aliases if DJANGO_16 else self.query.ordering_aliases
 		if result_type == constants.SINGLE:
 			if ordering_aliases:
@@ -139,7 +137,7 @@ class SQLCompiler(compiler.SQLCompiler):
 
 class SalesforceWhereNode(where.WhereNode):
 	overridden_types = ['isnull']
-	
+
 	def sql_for_columns(self, data, qn, connection, internal_type=None):  # Fixed for Django 1.6
 		"""
 		Don't attempt to quote column names.
@@ -153,7 +151,7 @@ class SalesforceWhereNode(where.WhereNode):
 	def make_atom(self, child, qn, connection):
 		lvalue, lookup_type, value_annot, params_or_value = child
 		result = super(SalesforceWhereNode, self).make_atom(child, qn, connection)
-		
+
 		if(lookup_type in self.overridden_types):
 			if hasattr(lvalue, 'process'):
 				try:
@@ -166,13 +164,144 @@ class SalesforceWhereNode(where.WhereNode):
 			else:
 				# A smart object with an as_sql() method.
 				field_sql = lvalue.as_sql(qn, connection)
-		
+
 			if lookup_type == 'isnull':
 				return ('%s %snull' % (field_sql,
 					(not value_annot and '!= ' or '= ')), ())
 		else:
 			return result
 
+	if(DJANGO_14):
+		def as_sql(self, qn, connection):
+			"""
+			Returns the SQL version of the where clause and the value to be
+			substituted in. Returns None, None if this node is empty.
+
+			If 'node' is provided, that is the root of the SQL generation
+			(generally not needed except by the internal implementation for
+			recursion).
+			"""
+			if not self.children:
+				return None, []
+			result = []
+			result_params = []
+			empty = True
+			for child in self.children:
+				try:
+					if hasattr(child, 'as_sql'):
+						sql, params = child.as_sql(qn=qn, connection=connection)
+					else:
+						# A leaf node in the tree.
+						sql, params = self.make_atom(child, qn, connection)
+
+				except EmptyResultSet:
+					if self.connector == AND and not self.negated:
+						# We can bail out early in this particular case (only).
+						raise
+					elif self.negated:
+						empty = False
+					continue
+				except FullResultSet:
+					if self.connector == OR:
+						if self.negated:
+							empty = True
+							break
+						# We match everything. No need for any constraints.
+						return '', []
+					if self.negated:
+						empty = True
+					continue
+
+				empty = False
+				if sql:
+					result.append(sql)
+					result_params.extend(params)
+			if empty:
+				raise EmptyResultSet
+
+			conn = ' %s ' % self.connector
+			sql_string = conn.join(result)
+			if sql_string:
+				if self.negated:
+					# SOQL requires us to wrap each fragment
+					negated_strings = ["(NOT(%s))" % fragment for fragment in result]
+					sql_string = conn.join(negated_strings)
+					# sql_string = 'NOT (%s)' % sql_string
+				elif len(self.children) != 1:
+					sql_string = '(%s)' % sql_string
+			return sql_string, result_params
+	elif(DJANGO_15 or DJANGO_16):
+		def as_sql(self, qn, connection):
+			"""
+			Returns the SQL version of the where clause and the value to be
+			substituted in. Returns '', [] if this node matches everything,
+			None, [] if this node is empty, and raises EmptyResultSet if this
+			node can't match anything.
+			"""
+			# Note that the logic here is made slightly more complex than
+			# necessary because there are two kind of empty nodes: Nodes
+			# containing 0 children, and nodes that are known to match everything.
+			# A match-everything node is different than empty node (which also
+			# technically matches everything) for backwards compatibility reasons.
+			# Refs #5261.
+			result = []
+			result_params = []
+			everything_childs, nothing_childs = 0, 0
+			non_empty_childs = len(self.children)
+
+			for child in self.children:
+				try:
+					if hasattr(child, 'as_sql'):
+						sql, params = child.as_sql(qn=qn, connection=connection)
+					else:
+						# A leaf node in the tree.
+						sql, params = self.make_atom(child, qn, connection)
+				except EmptyResultSet:
+					nothing_childs += 1
+				else:
+					if sql:
+						result.append(sql)
+						result_params.extend(params)
+					else:
+						if sql is None:
+							# Skip empty childs totally.
+							non_empty_childs -= 1
+							continue
+						everything_childs += 1
+				# Check if this node matches nothing or everything.
+				# First check the amount of full nodes and empty nodes
+				# to make this node empty/full.
+				if self.connector == AND:
+					full_needed, empty_needed = non_empty_childs, 1
+				else:
+					full_needed, empty_needed = 1, non_empty_childs
+				# Now, check if this node is full/empty using the
+				# counts.
+				if empty_needed - nothing_childs <= 0:
+					if self.negated:
+						return '', []
+					else:
+						raise EmptyResultSet
+				if full_needed - everything_childs <= 0:
+					if self.negated:
+						raise EmptyResultSet
+					else:
+						return '', []
+
+			if non_empty_childs == 0:
+				# All the child nodes were empty, so this one is empty, too.
+				return None, []
+			conn = ' %s ' % self.connector
+			sql_string = conn.join(result)
+			if sql_string:
+				if self.negated:
+					# SOQL requires us to wrap each fragment
+					negated_strings = ["(NOT(%s))" % fragment for fragment in result]
+					sql_string = conn.join(negated_strings)
+				elif len(result) > 1:
+					sql_string = '(%s)' % sql_string
+			return sql_string, result_params
+
 class SQLInsertCompiler(compiler.SQLInsertCompiler, SQLCompiler):
 	if(DJANGO_14):
 		def execute_sql(self, return_id=False):
